diff --git a/include/config.h b/include/config.h
index 9caadec8..b9ef340b 100644
--- a/include/config.h
+++ b/include/config.h
@@ -40,7 +40,7 @@ struct sway_mode {
  */
 struct output_config {
 	char *name;
-	bool enabled;
+	int enabled;
 	int width, height;
 	int x, y;
 	char *background;
@@ -99,6 +99,7 @@ bool read_config(FILE *file, bool is_active);
  */
 char *do_var_replacement(char *str);
 int output_name_cmp(const void *item, const void *data);
+void merge_output_config(struct output_config *dst, struct output_config *src);
 /** Sets up a WLC output handle based on a given output_config.
  */
 void apply_output_config(struct output_config *oc, swayc_t *output);
diff --git a/sway/config.c b/sway/config.c
index 67b442ad..aa4675ce 100644
--- a/sway/config.c
+++ b/sway/config.c
@@ -271,6 +271,42 @@ int output_name_cmp(const void *item, const void *data) {
 	return strcmp(output->name, name);
 }
 
+void merge_output_config(struct output_config *dst, struct output_config *src) {
+	if (src->name) {
+		if (dst->name) {
+			free(dst->name);
+		}
+		dst->name = strdup(src->name);
+	}
+	if (src->enabled != -1) {
+		dst->enabled = src->enabled;
+	}
+	if (src->width != -1) {
+		dst->width = src->width;
+	}
+	if (src->height != -1) {
+		dst->height = src->height;
+	}
+	if (src->x != -1) {
+		dst->x = src->x;
+	}
+	if (src->y != -1) {
+		dst->y = src->y;
+	}
+	if (src->background) {
+		if (dst->background) {
+			free(dst->background);
+		}
+		dst->background = strdup(src->background);
+	}
+	if (src->background_option) {
+		if (dst->background_option) {
+			free(dst->background_option);
+		}
+		dst->background_option = strdup(src->background_option);
+	}
+}
+
 void apply_output_config(struct output_config *oc, swayc_t *output) {
 	if (oc && oc->width > 0 && oc->height > 0) {
 		output->width = oc->width;
diff --git a/sway/commands.c b/sway/commands.c
index d6ee4553..307196a3 100644
--- a/sway/commands.c
+++ b/sway/commands.c
@@ -719,7 +719,7 @@ static struct cmd_results *cmd_output(int argc, char **argv) {
 	struct output_config *output = calloc(1, sizeof(struct output_config));
 	output->x = output->y = output->width = output->height = -1;
 	output->name = strdup(name);
-	output->enabled = true;
+	output->enabled = -1;
 
 	// TODO: atoi doesn't handle invalid numbers
 
@@ -728,7 +728,7 @@ static struct cmd_results *cmd_output(int argc, char **argv) {
 		const char *command = argv[i];
 
 		if (strcasecmp(command, "disable") == 0) {
-			output->enabled = false;
+			output->enabled = 0;
 		} else if (strcasecmp(command, "resolution") == 0 || strcasecmp(command, "res") == 0) {
 			if (++i >= argc) {
 				return cmd_results_new(CMD_INVALID, "output", "Missing resolution argument.");
@@ -815,15 +815,17 @@ static struct cmd_results *cmd_output(int argc, char **argv) {
 
 	i = list_seq_find(config->output_configs, output_name_cmp, name);
 	if (i >= 0) {
 		// replace existing config
 		struct output_config *oc = config->output_configs->items[i];
-		list_del(config->output_configs, i);
-		free_output_config(oc);
+		merge_output_config(oc, output);
+		free_output_config(output);
+		output = oc;
+	} else {
+		list_add(config->output_configs, output);
 	}
-	list_add(config->output_configs, output);
 
-	sway_log(L_DEBUG, "Config stored for output %s (%s) (%d x %d @ %d, %d) (bg %s %s)",
-			output->name, output->enabled ? "enable" : "disable", output->width,
+	sway_log(L_DEBUG, "Config stored for output %s (enabled:%d) (%d x %d @ %d, %d) (bg %s %s)",
+			output->name, output->enabled, output->width,
 			output->height, output->x, output->y, output->background,
 			output->background_option);
 
@@ -815,15 +815,17 @@ static struct cmd_results *cmd_output(int argc, char **argv) {
 	i = list_seq_find(config->output_configs, output_name_cmp, name);
 	if (i >= 0) {
-		// replace existing config
+		// merge existing config
 		struct output_config *oc = config->output_configs->items[i];